/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.Connection;
import nl.cloudfarming.client.isobus.model.DeviceElement;
import nl.cloudfarming.client.isobus.model.IsobusDevice;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;

/**
 * <p>Child factory for the {@link Connection} object</p> <p>Possible children
 * are 2 times {@link IsobusDevicece} and 2 times {@link DeviceElement}</p>
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
public class ConnectionChildFactory extends ChildFactory<Node> {
    
    private Connection connection;
    
    public ConnectionChildFactory(Connection connection) {
        this.connection = connection;        
    }
    
    @Override
    protected boolean createKeys(List<Node> toPopulate) {
        //Device (DVC) Device ref 1
        IsobusDevice device1 = (IsobusDevice) connection.getDeviceId0();
        if (device1 != null) {
            toPopulate.add(new DeviceNode(device1));
        }

        //DeviceElement (DET) Device element ref 1
        DeviceElement deviceElement1 = (DeviceElement) connection.getDeviceElementId0();
        if(deviceElement1 != null){
            toPopulate.add(new DeviceElementNode(deviceElement1));
        }

        //Device (DVC) Device ref 2
        IsobusDevice device2 = (IsobusDevice) connection.getDeviceId1();
        if (device1 != null) {
            toPopulate.add(new DeviceNode(device2));
        }
        //DeviceElement (DET) Device element ref 2
        DeviceElement deviceElement2 = (DeviceElement) connection.getDeviceElementId1();
        if(deviceElement1 != null){
            toPopulate.add(new DeviceElementNode(deviceElement2));
        }
        
        return true;
    }
    
    @Override
    protected Node createNodeForKey(Node key) {
        return key;
    }
}
