/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.AllocationTime;
import nl.cloudfarming.client.isobus.model.DeviceAllocation;
import nl.cloudfarming.client.isobus.model.IsobusDevice;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;

/**
 * <p>Child factory for {@link DeviceAllocation} object</p>
 * <p>Possible children {@link AllocationTime} and {@link IsobusDevice}</p>
 * @author Gerben Feenstra
 */
public class DeviceAllocationChildFactory extends ChildFactory<Node> {

    private final DeviceAllocation deviceAllocation;

    public DeviceAllocationChildFactory(DeviceAllocation deviceAllocation) {
        this.deviceAllocation = deviceAllocation;
    }

    @Override
    protected boolean createKeys(List<Node> toPopulate) {

        //AllocationStamp (ASP)
        AllocationTime allocationTime = deviceAllocation.getAllocationStamp();
        if (allocationTime != null) {
            toPopulate.add(new AllocationStampNode(allocationTime));
        }
        //Device DVC
        IsobusDevice isobusDevice = (IsobusDevice) deviceAllocation.getDeviceId();
        if(isobusDevice != null){
            toPopulate.add(new DeviceNode(isobusDevice));
        }
        return true;
    }

    @Override
    protected Node createNodeForKey(Node node) {
        return node;
    }
}
