/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.IsobusProduct;
import nl.cloudfarming.client.isobus.model.ProductGroup;
import nl.cloudfarming.client.isobus.model.ValuePresentation;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;
import org.openide.util.lookup.Lookups;

/**
 * Node for the {@link IsobusProduct} object
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages({"isobus project taskdata node name product=Product ({0})"})
public class ProductNode extends AbstractNode {

    private static final String PRODUCT_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_product.png";

    public ProductNode(IsobusProduct isobusProduct) {
        super(Children.create(new ProductChildFactory(isobusProduct), true), Lookups.fixed(isobusProduct));
        setName(Bundle.isobus_project_taskdata_node_name_product(isobusProduct.getProductDesigNator()));
        setIconBaseWithExtension(PRODUCT_ICON);

    }

    /**
     * <p>Child factory for {@link IsobusProduct}</p> <p>Possible children are {@link ProductGroup}
     * and {@link ValuePresentation}</p>
     *
     * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
     */
    @NbBundle.Messages({"isobus project taskdata node name product group=Product group ({0})"})
    static class ProductChildFactory extends ChildFactory<Node> {

        private IsobusProduct isobusProduct;
        private static final String PRODUCT_GROUP_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_productgroup.png";

        ProductChildFactory(IsobusProduct isobusProduct) {
            this.isobusProduct = isobusProduct;
        }

        @Override
        protected boolean createKeys(List<Node> toPopulate) {
            //ProductGroup (PGP)
            ProductGroup productGroup = (ProductGroup) isobusProduct.getProductGroupId();
            if(productGroup != null){
                toPopulate.add(new IsobusCommonNode(Children.LEAF, productGroup, PRODUCT_GROUP_ICON, Bundle.isobus_project_taskdata_node_name_product_group(productGroup.getProductGRoupDesignator())));
            }
            //ValuePresentation (VPN)
            ValuePresentation valuePresentation = (ValuePresentation) isobusProduct.getValuePresentationIdRef();
            if(valuePresentation != null){
                toPopulate.add(new ValuePresentationNode(valuePresentation));
            }
            return true;
        }

        @Override
        protected Node createNodeForKey(Node key) {
            return key;
        }
    }
}
