/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.DataLogValue;
import nl.cloudfarming.client.isobus.model.IsobusTime;
import nl.cloudfarming.client.isobus.model.Position;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle.Messages;

/**
 * Node factory for the {@link IsobusTime} Object Possible children are {@link Position}
 * and {@link DataLogValue}
 *
 * @author Gerben Feenstra
 */
@Messages({
    "isobus project taskdata node name datalog values=Datalog values"
})
public class TimeChildFactory extends ChildFactory<Node> {

    private static final String DATALOGVALUE_NODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_data_log_value.png";
    private final IsobusTime time;

    public TimeChildFactory(IsobusTime time) {
        this.time = time;
    }

    @Override
    protected boolean createKeys(List<Node> toPopulate) {
        // Position (PTN)
        Position position = time.getPTN();
        if (position != null) {
            toPopulate.add(new PositionNode(position));
        }

        // DataLogValue (DLV)
        if (!time.getDLV().isEmpty()) {
            Children dataLogValueChildren = Children.create(new AggregateNodeChildFactory<>(time.getDLV()), true);
            String displayName = Bundle.isobus_project_taskdata_node_name_datalog_values();
            toPopulate.add(new IsobusAggregateNode(dataLogValueChildren, DATALOGVALUE_NODE_ICON, displayName));
        }
        return true;
    }

    @Override
    protected Node createNodeForKey(Node node) {
        return node;
    }
}
