/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.ColorRange;
import nl.cloudfarming.client.isobus.model.IsobusColor;
import nl.cloudfarming.client.isobus.model.ValuePresentation;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;
import org.openide.util.lookup.Lookups;

/**
 * Node for the {@link ValuePresentation} object
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages({"isobus project taskdata node name value presentation=Value presentation ({0})"})
public class ValuePresentationNode extends AbstractNode {

    private static final String VALUE_PRESENTATION_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_value_presentation.png";

    public ValuePresentationNode(ValuePresentation valuePresentation) {
        super(Children.create(new ValuePresentationChildFactory(valuePresentation), true), Lookups.fixed(valuePresentation));
        setName(Bundle.isobus_project_taskdata_node_name_value_presentation(valuePresentation.getUnitDesignator()));
        setIconBaseWithExtension(VALUE_PRESENTATION_ICON);
    }

    /**
     * <p>Child factory for {@link ValuePresentation} objects</p> <p>Possible
     * children are {@link IsobusColor}</p>
     *
     * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
     */
    @NbBundle.Messages({"isobus project taskdata node name color=Color ({0})"})
    static class ValuePresentationChildFactory extends ChildFactory<IsobusColor> {

        private static final String COLOR_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_color.png";
        private final ValuePresentation valuePresentation;

        public ValuePresentationChildFactory(ValuePresentation valuePresentation) {
            this.valuePresentation = valuePresentation;
        }

        @Override
        protected boolean createKeys(List<IsobusColor> toPopulate) {
            //isobusColor (CLD)
            IsobusColor color = (IsobusColor) valuePresentation.getColorLegendIdRef();
            if (color != null) {
                toPopulate.add(color);
            }
            return true;
        }

        @Override
        protected Node createNodeForKey(IsobusColor color) {
            Children colorChildren = Children.create(new ColorChildFactory(color), true);
            return new IsobusCommonNode(colorChildren, color, COLOR_ICON, Bundle.isobus_project_taskdata_node_name_color(color.getId()));
        }
        
        /**
         * <p>Child factory for the {@link IsobusColor} object</p>
         * <p>Possible children are {@link ColorRange}</p>
         * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
         */
        @NbBundle.Messages({"isobus project taskdata node name color range=Color range({0})"})
        class ColorChildFactory extends ChildFactory<ColorRange>{

            private IsobusColor color;
            private static final String COLOR_RANGE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_color_range.png";
            
            public ColorChildFactory(IsobusColor color){
                this.color = color;
            }
            
            @Override
            protected boolean createKeys(List<ColorRange> toPopulate) {
                if(!color.getColorRange().isEmpty()){
                    toPopulate.addAll(color.getColorRange());
                }
                return true;
            }
            
            @Override
            protected Node createNodeForKey(ColorRange colorRange) {
                return new IsobusCommonNode(Children.LEAF, colorRange, COLOR_RANGE_ICON, Bundle.isobus_project_taskdata_node_name_color_range(colorRange.getValue()));
            }
            
        }
    }
}
