/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.AllocationTime;
import nl.cloudfarming.client.isobus.model.IsobusWorker;
import nl.cloudfarming.client.isobus.model.WorkerAllocation;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;

/**
 * Child factory for {@link WorkerAllocation} objects
 * Possible children {@link IsobusWorker} and {@link AllocationTime}
 * @author Gerben Feenstra
 */
public class WorkerAllocationChildFactory extends ChildFactory<Node> {

    private final WorkerAllocation workerAllocation;

    public WorkerAllocationChildFactory(WorkerAllocation workerAllocation) {
        this.workerAllocation = workerAllocation;
    }
    
    @Override
    protected boolean createKeys(List<Node> toPopulate) {
        //Worker (WKR)
        IsobusWorker worker = (IsobusWorker) workerAllocation.getWorkerIdRef();
        if(worker != null){
            toPopulate.add(new WorkerNode(worker));
        }
        
        //AllocationStamp (ASP)
        AllocationTime allocationStamp = workerAllocation.getAllocationStamp();
        if(allocationStamp != null){ 
            toPopulate.add(new AllocationStampNode(allocationStamp));
        }
        
        return true;
    }

    @Override
    protected Node createNodeForKey(Node node) {
        return node;
    }
}
